@@ -6,6 +6,8 @@
 #include <function/VectorFunction.h>
 #include <function/ArrayFunction.h>
 
+namespace jags {
+
 /**
  * @short Polymorphic pointer to Function
  *
@@ -36,4 +38,6 @@ public:
     friend bool isNULL(FunctionPtr const &p);
 };
 
+} /* namespace jags */
+
 #endif /* FUNCTION_POINTER_H_ */
