@@ -3,6 +3,8 @@
 
 #include <graph/StochasticNode.h>
 
+namespace jags {
+
 class VectorDist;
 
 /**
@@ -19,7 +21,7 @@ public:
      * a vector of parent nodes, considered as parameters to the
      * distribution.
      */
-    VectorStochasticNode(VectorDist const *dist,
+    VectorStochasticNode(VectorDist const *dist, unsigned int nchain,
 			 std::vector<Node const *> const &parameters,
 			 Node const *lower, Node const *upper);
     double logDensity(unsigned int chain, PDFType type) const;
@@ -28,10 +30,14 @@ public:
 			 double const *lower, double const *upper);
     void deterministicSample(unsigned int chain);
     bool checkParentValues(unsigned int chain) const;
-    StochasticNode *clone(std::vector<Node const *> const &parents,
-			  Node const *lower, Node const *upper) const;
+    //StochasticNode *clone(std::vector<Node const *> const &parents,
+    //Node const *lower, Node const *upper) const;
     unsigned int df() const;
+    double KL(unsigned int chain1, unsigned int chain2, RNG *rng,
+	      unsigned int nrep) const;
 };
 
+} /* namespace jags */
+
 #endif /* VECTOR_STOCHASTIC_NODE_H_ */
 
