@@ -3,6 +3,8 @@
 
 #include <string>
 
+namespace jags {
+
 class Node;
 class Distribution;
 class Function;
@@ -13,4 +15,6 @@ void throwNodeError(Node const *node, std::string const &message);
 void throwDistError(Distribution const *dist, std::string const &message);
 void throwFuncError(Function const *func, std::string const &message);
 
+} /* namespace jags */
+
 #endif /* MODULE_ERROR_H_ */
