@@ -1,7 +1,11 @@
 #ifndef UTIL_INTEGER_H_
 #define UTIL_INTEGER_H_
 
+namespace jags {
+
 bool checkInteger(double);
 int asInteger(double);
 
+} /* namespace jags */
+
 #endif /* UTIL_INTEGER_H_ */
