@@ -1,7 +1,7 @@
 /*
  *  Mathlib : A C Library of Special Functions
  *  Copyright (C) 1998 Ross Ihaka
- *  Copyright (C) 2000-2001 The R Development Core Team
+ *  Copyright (C) 2000-2014 The R Core Team
  *  Copyright (C) 2005	The R Foundation
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -42,6 +42,7 @@
  */
 
 #include "nmath.h"
+#include "dpq.h"
 
 /* afc(i) :=  ln( i! )	[logarithm of the factorial i.
  *	   If (i > 7), use Stirling's approximation, otherwise use table lookup.
@@ -78,7 +79,7 @@ static double afc(int i)
     return value;
 }
 
-double rhyper(double nn1in, double nn2in, double kkin, RNG *rng)
+double rhyper(double nn1in, double nn2in, double kkin, JRNG *rng)
 {
     const static double con = 57.56462733;
     const static double deltal = 0.0078;
@@ -111,9 +112,9 @@ double rhyper(double nn1in, double nn2in, double kkin, RNG *rng)
     if(!R_FINITE(nn1in) || !R_FINITE(nn2in) || !R_FINITE(kkin))
 	ML_ERR_return_NAN;
 
-    nn1 = floor(nn1in+0.5);
-    nn2 = floor(nn2in+0.5);
-    kk	= floor(kkin +0.5);
+    nn1 = (int) R_forceint(nn1in);
+    nn2 = (int) R_forceint(nn2in);
+    kk	= (int) R_forceint(kkin);
 
     if (nn1 < 0 || nn2 < 0 || kk < 0 || kk > nn1 + nn2)
 	ML_ERR_return_NAN;
@@ -142,13 +143,13 @@ double rhyper(double nn1in, double nn2in, double kkin, RNG *rng)
     if (setup2) {
 	ks = kk;
 	if (kk + kk >= tn) {
-	    k = tn - kk;
+	    k = (int)(tn - kk);
 	} else {
 	    k = kk;
 	}
     }
     if (setup1 || setup2) {
-	m = (k + 1.0) * (n1 + 1.0) / (tn + 2.0);
+	m = (int) ((k + 1.0) * (n1 + 1.0) / (tn + 2.0));
 	minjx = imax2(0, k - n2);
 	maxjx = imin2(n1, k);
     }
@@ -225,14 +226,14 @@ double rhyper(double nn1in, double nn2in, double kkin, RNG *rng)
 	u = unif_rand(rng) * p3;
 	v = unif_rand(rng);
 	if (u < p1) {		/* rectangular region */
-	    ix = xl + u;
+	    ix = (int) (xl + u);
 	} else if (u <= p2) {	/* left tail */
-	    ix = xl + log(v) / lamdl;
+	    ix = (int) (xl + log(v) / lamdl);
 	    if (ix < minjx)
 		goto L30;
 	    v = v * (u - p1) * lamdl;
 	} else {		/* right tail */
-	    ix = xr - log(v) / lamdr;
+	    ix = (int) (xr - log(v) / lamdr);
 	    if (ix > maxjx)
 		goto L30;
 	    v = v * (u - p2) * lamdr;
