@@ -1,7 +1,7 @@
 /*
  *  Mathlib : A C Library of Special Functions
  *  Copyright (C) 1998 Ross Ihaka
- *  Copyright (C) 2000--2006  The R Development Core Team
+ *  Copyright (C) 2000--2006  The R Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 
 #include "nmath.h"
 
-double rnbinom(double size, double prob, RNG *rng)
+double rnbinom(double size, double prob, JRNG *rng)
 {
     if(!R_FINITE(size) || !R_FINITE(prob) || size <= 0 || prob <= 0 || prob > 1)
 	/* prob = 1 is ok, PR#1218 */
@@ -52,7 +52,7 @@ double rnbinom(double size, double prob, RNG *rng)
     return (prob == 1) ? 0 : rpois(rgamma(size, (1 - prob) / prob, rng), rng);
 }
 
-double rnbinom_mu(double size, double mu, RNG *rng)
+double rnbinom_mu(double size, double mu, JRNG *rng)
 {
     if(!R_FINITE(size) || !R_FINITE(mu) || size <= 0 || mu < 0)
 	ML_ERR_return_NAN;
