@@ -17,8 +17,8 @@
  * pvariables will point to a newly allocated ParseTree representing
  * the stochastic and logical relationships between declared nodes.
  */
-int parse_bugs(std::FILE *file, std::vector<ParseTree*> * &pvariables, 
-	       ParseTree * &pdata, ParseTree * &prelations,
+int parse_bugs(std::FILE *file, std::vector<jags::ParseTree*> * &pvariables, 
+	       jags::ParseTree * &pdata, jags::ParseTree * &prelations,
 	       std::string &message);
 
 #endif /* PARSER_EXTRA_H_ */
