@@ -4,7 +4,11 @@
 
 using std::string;
 
+namespace jags {
+
 FuncError::FuncError(Function const *efunc, string const &emsg)
     : runtime_error(emsg + " in function " + efunc->name())
 {
 }
+
+} //namespace jags
