@@ -1,6 +1,6 @@
 #include <config.h>
 #include <graph/ScalarStochasticNode.h>
-#include <distribution/DistError.h>
+#include <graph/NodeError.h>
 #include <distribution/ScalarDist.h>
 #include <util/nainf.h>
 
@@ -10,15 +10,27 @@
 using std::vector;
 using std::string;
 
-ScalarStochasticNode::ScalarStochasticNode(ScalarDist const *dist, 
+namespace jags {
+
+ScalarStochasticNode::ScalarStochasticNode(ScalarDist const *dist,
+					   unsigned int nchain,
 					   vector<Node const *> const &params,
 					   Node const *lower, Node const *upper)
-    : StochasticNode(vector<unsigned int>(1,1), dist, params, lower, upper), 
+    : StochasticNode(vector<unsigned int>(1,1), nchain, dist, params, lower, upper),
       _dist(dist)
 {
-    for (unsigned int i = 0; i < params.size(); ++i) {
-	if (params[i]->length() != 1) {
-	    throw DistError(dist, "Invalid non-scalar parameter");
+    for(vector<Node const *>::const_iterator p = params.begin();
+	p != params.end(); ++p)
+    {
+	if ((*p)->length()==0) {
+	    string msg("Invalid zero-length parameter in distribution ");
+	    msg.append(dist->name());
+	    throw NodeError(*p, msg);
+	}
+	else if ((*p)->length() > 1) {
+	    string msg("Invalid vector parameter in distribution ");
+	    msg.append(dist->name());
+	    throw NodeError(*p, msg);
 	}
     }
 }
@@ -70,13 +82,15 @@ bool isBounded(ScalarStochasticNode const *node)
     return node->lowerBound() || node->upperBound();
 }
 
+    /*
 StochasticNode * 
 ScalarStochasticNode::clone(vector<Node const *> const &parameters,
 			    Node const *lower, Node const *upper) const
 {
     return new ScalarStochasticNode(_dist, parameters, lower, upper);
 }
-
+    */
+    
 unsigned int ScalarStochasticNode::df() const
 {
     return _dist->df();
@@ -88,3 +102,34 @@ void ScalarStochasticNode::sp(double *lower, double *upper, unsigned int length,
     *lower = _dist->l(_parameters[chain]);
     *upper = _dist->u(_parameters[chain]);
 }
+
+    double ScalarStochasticNode::KL(unsigned int ch1, unsigned int ch2,
+				    RNG *rng, unsigned int nrep) const
+    {
+	if (lowerBound() || upperBound()) {
+	    Node const *ll = lowerBound();
+	    Node const *uu = upperBound();
+	    if (ll && !ll->isFixed()) {
+		return JAGS_POSINF;
+	    }
+	    if (uu &&  !uu->isFixed()) {
+		return JAGS_POSINF;
+	    }
+	    return _dist->KL(_parameters[ch1], _parameters[ch2],
+			     lowerLimit(ch1), upperLimit(ch1),
+			     rng, nrep);
+	}
+	else {
+	    double kl =  _dist->KL(_parameters[ch1], _parameters[ch2]);
+	    if (kl == JAGS_NA) {
+		return _dist->KL(_parameters[ch1], _parameters[ch2],
+				 0, 0, rng, nrep);
+	    }
+	    else {
+		return kl;
+	    }
+	}
+    }
+    
+
+} //namespace jags
