@@ -4,6 +4,7 @@
 using std::vector;
 using std::string;
 
+namespace jags {
 namespace base {
 
 Not::Not () : ScalarFunction ("!", 1)
@@ -12,7 +13,7 @@ Not::Not () : ScalarFunction ("!", 1)
 
 double Not::evaluate(vector<double const*> const &args) const
 {
-    return *args[0] != 0;
+    return *args[0] == 0;
 }
 
 bool Not::isDiscreteValued(vector<bool> const &mask) const
@@ -25,4 +26,4 @@ string Not::deparse(vector<string> const &par) const
     return string("!") + par[0];
 }
 
-}
+}}
