@@ -3,8 +3,7 @@
 
 #include <distribution/VectorDist.h>
 
-struct RNG;
-
+namespace jags {
 namespace bugs {
 
 /**
@@ -58,11 +57,11 @@ public:
 		 std::vector<unsigned int> const &lengths) const;
     bool isSupportFixed(std::vector<bool> const &fixmask) const;
     unsigned int df(std::vector<unsigned int> const &lengths) const;
-    double KL(std::vector<double const *> const &par1,
-	      std::vector<double const *> const &par2,
+    double KL(std::vector<double const *> const &par0,
+	      std::vector<double const *> const &par1,
 	      std::vector<unsigned int> const &len) const;
 };
 
-}
+}}
 
 #endif /* DDIRCH_H_ */
