@@ -1,8 +1,9 @@
 #ifndef DGAMMA_H_
 #define DGAMMA_H_
 
-#include "RScalarDist.h"
+#include <distribution/RScalarDist.h>
 
+namespace jags {
 namespace bugs {
 
 /**
@@ -32,10 +33,10 @@ class DGamma : public RScalarDist {
    */
   double  typicalValue(std::vector<double const *> const &par,
 		       double const *lower, double const *upper) const;
-  double KL(std::vector<double const *> const &par1,
-	    std::vector<double const *> const &par2) const;
+  double KL(std::vector<double const *> const &par0,
+	    std::vector<double const *> const &par1) const;
 };
 
-}
+}}
 
 #endif /* DGAMMA_H_ */
