@@ -3,6 +3,7 @@
 
 #include <function/ScalarFunction.h>
 
+namespace jags {
 namespace bugs {
 
     /**
@@ -21,7 +22,7 @@ namespace bugs {
 	bool isDiscreteValued(std::vector<bool> const &mask) const;
     };
 
-}
+}}
 
 
 #endif /* FUNC_ABS_H_ */
