@@ -3,6 +3,7 @@
 
 #include <function/ArrayFunction.h>
 
+namespace jags {
 namespace bugs {
 
     /**
@@ -24,11 +25,12 @@ namespace bugs {
 	    const;
 	bool checkParameterDim(std::vector<std::vector<unsigned int> > const &dims) const;
 	std::vector<unsigned int>
-	    dim(std::vector<std::vector<unsigned int> > const &dims) const;
+	    dim(std::vector<std::vector<unsigned int> > const &dims,
+		std::vector<double const *> const &values) const;
 	bool checkParameterValue(std::vector<double const *> const &args,
 				 std::vector<std::vector<unsigned int> > const &dims) const;
     };
 
-}
+}}
 
 #endif /* LOG_DET_H_ */
