@@ -6,6 +6,7 @@
 using std::vector;
 using std::log;
 
+namespace jags {
 namespace bugs {
 
     Logit::Logit ():ScalarFunction ("logit", 1)
@@ -18,10 +19,10 @@ namespace bugs {
 	return log(arg) - log(1 - arg);
     }
 
-    bool Logit::checkScalarValue (vector <double const *> const &args) const
+    bool Logit::checkParameterValue (vector <double const *> const &args) const
     {
 	double arg = *args[0];
 	return (arg >= 0 && arg <= 1);
     }
 
-}
+}}
