@@ -3,8 +3,11 @@
 
 #include <JRmath.h>
 
+#include <cfloat>
+
 using std::vector;
 
+namespace jags {
 namespace bugs {
 
     Phi::Phi () : LinkFunction ("phi", "probit")
@@ -35,4 +38,4 @@ namespace bugs {
 	return dnorm (eta, 0, 1, 0);
     }
 
-}
+}}
