@@ -1,8 +1,9 @@
 #ifndef FUNC_SUM_H_
 #define FUNC_SUM_H_
 
-#include <function/VectorFunction.h>
+#include <function/ScalarVectorFunction.h>
 
+namespace jags {
 namespace bugs {
 
     /**
@@ -13,18 +14,19 @@ namespace bugs {
      * y <- sum(x[])
      * </pre>
      */
-    class Sum : public VectorFunction
+    class Sum : public ScalarVectorFunction
     {
     public:
 	Sum ();
-	void evaluate(double *x, std::vector <double const *> const &args,
-		      std::vector<unsigned int> const &lengths) const;
-	bool checkParameterLength(std::vector<unsigned int> const &args) const;
+	double scalarEval(std::vector <double const *> const &args,
+			  std::vector<unsigned int> const &lengths) const;
 	bool isDiscreteValued(std::vector<bool> const &mask) const;
+	bool isAdditive(std::vector<bool> const &mask,
+			std::vector<bool> const &isfixed) const;
 	bool isScale(std::vector<bool> const &mask,
 		     std::vector<bool> const &isfixed) const;
     };
     
-}
+}}
 
 #endif /* FUNC_SUM_H_ */
