@@ -3,6 +3,10 @@
 
 #include "ConjugateMethod.h"
 
+namespace jags {
+
+    class Graph;
+
 namespace bugs {
 
 /**
@@ -15,12 +19,11 @@ namespace bugs {
  */
 class ConjugateWishart : public ConjugateMethod {
 public:
-    ConjugateWishart(GraphView const *gv);
+    ConjugateWishart(SingletonGraphView const *gv);
     void update(unsigned int chain, RNG *rng) const;
     static bool canSample(StochasticNode *snode, Graph const &graph);
-    std::string name() const;
 };
 
-}
+}}
 
 #endif /* CONJUGATE_WISHART_H_ */
