@@ -5,6 +5,7 @@
 
 class StochasticNode;
 
+namespace jags {
 namespace bugs {
 
 /**
@@ -16,9 +17,8 @@ public:
     DiscreteDSum(GraphView const *gv, unsigned int chain);
     void step(std::vector<double> &value, unsigned int nrow,
 	      unsigned int ncol, double s, RNG *rng) const;
-    std::string name() const;
 };
 
-}
+}}
 
 #endif /* DISCRETE_DSUM_H_ */
