@@ -1,8 +1,5 @@
 #include "PDTraceFactory.h"
 #include "PDTrace.h"
-#include "KLTab.h"
-#include "CalKLExact.h"
-#include "CalKLApprox.h"
 
 #include <model/BUGSModel.h>
 #include <graph/StochasticNode.h>
@@ -14,13 +11,9 @@ using std::set;
 using std::string;
 using std::vector;
 
+namespace jags {
 namespace dic {
 
-    static KL const *findKL(string const &name) {
-	static KLTab _kltab;
-	return _kltab.find(name);
-    }
-
     Monitor *PDTraceFactory::getMonitor(string const &name,
 					Range const &range,
 					BUGSModel *model,
@@ -43,7 +36,7 @@ namespace dic {
 	vector<StochasticNode const *> observed_nodes;
 	vector<StochasticNode *> const &snodes = model->stochasticNodes();
 	for (unsigned int i = 0; i < snodes.size(); ++i) {
-	    if (snodes[i]->isObserved()) {
+	    if (snodes[i]->isFixed()) {
 		observed_nodes.push_back(snodes[i]);
 	    }
 	    if (!isSupportFixed(snodes[i])) {
@@ -62,20 +55,7 @@ namespace dic {
 	    rngs.push_back(model->rng(i));
 	}
 
-	vector<CalKL*> calkl;
-	for (unsigned int i = 0; i < observed_nodes.size(); ++i) {
-	    
-	    StochasticNode const *snode = observed_nodes[i];
-	    KL const *kl = findKL(snode->distribution()->name());
-	    if (kl) {
-		calkl.push_back(new CalKLExact(snode, kl));
-	    }
-	    else {
-		calkl.push_back(new CalKLApprox(snode, rngs, 10));
-	    }
-	}
-
-	Monitor *m  = new PDTrace(observed_nodes, calkl);
+	Monitor *m  = new PDTrace(observed_nodes, rngs, 10);
 	m->setName("pD");
 	m->setElementNames(vector<string>(1,"pD"));
 	return m;
@@ -85,4 +65,5 @@ namespace dic {
     {
 	return "dic::PDTrace";
     }
-}
+
+}}
