@@ -4,6 +4,7 @@
 #include "GLMFactory.h"
 #include "AMMethod.h"
 
+namespace jags {
 namespace glm {
 
     /**
@@ -19,8 +20,7 @@ namespace glm {
 	 * Returns true if the outcome has a Poisson distribution with
 	 * log link, or a Binomial distribution with logit link.
 	 */
-	bool checkOutcome(StochasticNode const *snode,
-			  LinkNode const *lnode) const;
+	bool checkOutcome(StochasticNode const *snode) const;
 	/**
 	 * Returns true if the node is not bounded
 	 */
@@ -31,10 +31,10 @@ namespace glm {
 	 * with logistic link.
 	 */
 	GLMMethod * newMethod(GraphView const *view,
-			      std::vector<GraphView const *> const &sub_views, 
+			      std::vector<SingletonGraphView const *> const &sub_views, 
 			      unsigned int chain) const;
     };
 
-}
+}}
 
 #endif /* AM_FACTORY_H_ */
