@@ -3,6 +3,7 @@
 
 #include "BinaryFactory.h"
 
+namespace jags {
 namespace glm {
 
     /**
@@ -18,11 +19,12 @@ namespace glm {
 	 * Returns a newly allocated object of class AlbertChib for
 	 * sampling binary GLMs with probit or logistic link.
 	 */
-	BinaryGLM *newBinary(GraphView const *view, 
-			     std::vector<GraphView const *> const &sub_views,
+	GLMMethod *newBinary(GraphView const *view, 
+			     std::vector<SingletonGraphView const *> const &sub_views,
+			     std::vector<Outcome *> const &outcomes,
 			     unsigned int chain) const;
     };
 
-}
+}}
 
 #endif /* ALBERT_CHIB_FACTORY_H_ */
