@@ -1,15 +1,18 @@
 #include <config.h>
 #include "GLMSampler.h"
 #include <sampler/GraphView.h>
+#include <sampler/SingletonGraphView.h>
 
 using std::vector;
 
+namespace jags {
 namespace glm {
 
     GLMSampler::GLMSampler(GraphView *view, 
-			   vector<GraphView*> const &sub_views,
-			   vector<SampleMethod*> const &methods)
-	: ParallelSampler(view, methods), _sub_views(sub_views)
+			   vector<SingletonGraphView*> const &sub_views,
+			   vector<MutableSampleMethod*> const &methods,
+			   std::string const &name)
+	: MutableSampler(view, methods, name), _sub_views(sub_views)
     {
     }
     
@@ -21,4 +24,4 @@ namespace glm {
 	}
     }
 
-}
+}}
