@@ -3,6 +3,8 @@
 
 #include "GLMMethod.h"
 
+namespace jags {
+
 class LinkNode;
 
 namespace glm {
@@ -22,32 +24,15 @@ namespace glm {
      * effects models.
      */
     class IWLS : public GLMMethod {
-	std::vector<LinkNode const *> _link;
-	std::vector<GLMFamily> _family;
 	bool _init;
-	double _w;
-        double var(unsigned int i) const;
         double logPTransition(std::vector<double> const &xorig,
                               std::vector<double> const &x,
                               double *b, cholmod_sparse *A);
     public:
 	IWLS(GraphView const *view, 
-	     std::vector<GraphView const *> const &sub_views,
+	     std::vector<SingletonGraphView const *> const &sub_views,
+	     std::vector<Outcome *> const &outcomes,
 	     unsigned int chain);
-	/**
-	 * Returns "IWLS"
-	 */
-	std::string name() const;
-	/**
-	 * Returns the value of the outcome variable in a local linear
-	 * approximation to the GLM
-	 */
-	double getValue(unsigned int i) const;	
-	/**
-	 * Returns the precision of the outcome variable in a local
-	 * linear approximation to the GLM
-	 */
-	double getPrecision(unsigned int i) const;
 	/**
 	 * Generates a new proposal from an approximation to the posterior
 	 * distribution derived by a single IWLS step, then carries out
@@ -56,6 +41,6 @@ namespace glm {
 	void update(RNG *rng);
     };
 
-}
+}}
 
 #endif /* IWLS_H_ */
