@@ -3,6 +3,7 @@
 
 #include "GLMFactory.h"
 
+namespace jags {
 namespace glm {
 
     /**
@@ -17,20 +18,18 @@ namespace glm {
      */
     class LinearGibbsFactory : public GLMFactory
     {
-	bool _gibbs;
     public:
 	LinearGibbsFactory();
 	/**
 	 * Checks that the outcome variable is from a normal family
 	 * with identity link (i.e. lnode is NULL)
 	 */
-	bool checkOutcome(StochasticNode const *snode,
-			  LinkNode const *lnode) const;
+	bool checkOutcome(StochasticNode const *snode) const;
 	/**
 	 * Returns a newly allocated object of class Linear
 	 */
 	GLMMethod *newMethod(GraphView const *view, 
-			     std::vector<GraphView const *> const &sub_views,
+			     std::vector<SingletonGraphView const *> const &sub_views,
 			     unsigned int chain) const;
 	/**
 	 * Checks that the candidate node is scalar
@@ -38,6 +37,6 @@ namespace glm {
 	bool canSample(StochasticNode const *snode) const;
     };
 
-}
+}}
 
 #endif /* LINEAR_GIBBS_FACTORY_H_ */
