@@ -1,5 +1,4 @@
-#include <Module.h>
-#include <distribution/DistTab.h>
+#include <module/Module.h>
 
 #include <distributions/DMState.h>
 
@@ -7,6 +6,7 @@
 
 using std::vector;
 
+namespace jags {
 namespace msm {
 
     class MSMModule : public Module {
@@ -35,7 +35,8 @@ namespace msm {
 	    delete fvec[i];
 	}
     }
-}
+
+}}
  
-msm::MSMModule _msm_module;
+jags::msm::MSMModule _msm_module;
     
